oc\_ocdm.graph.entities.bibliographic.bibliographic\_resource module
--------------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.bibliographic_resource
   :members:
   :undoc-members:
   :show-inheritance:
